Coverage for soxspipe/recipes/__init__.py: 100%

# Coverage for soxspipe/recipes/__init__.py : 100%

## 6 statements 6 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1"""

2*The pipeline recipes*

3"""

4 from ._base_recipe_ import _base_recipe_

5 from .soxs_mbias import soxs_mbias

6 from .soxs_mdark import soxs_mdark

7 from .soxs_disp_solution import soxs_disp_solution

8 from .soxs_order_centres import soxs_order_centres

9 from .soxs_spatial_solution import soxs_spatial_solution